pub fn install_local_workspace(workspace: &Path) -> Result<()>Expand description
Build and activate the shipped Foundry binaries from an explicit workspace, without linking unused workspace binaries. Used to benchmark a baseline ref checked out into a separate worktree.